# -*- coding:utf8 -*-


def hello(country):
    upper_country = country.upper()
    if upper_country == 'KOR':
        print('안녕하세요!')
    elif upper_country == 'ENG':
        print('Hello!')
    else:
        print('안녕하세요, Hello!')